@@ -1,9 +1,9 @@
 from datetime import datetime, timedelta
-from typing import List
+from typing import List, Dict, Optional
 from pvpower.forecast import PvPowerForecast, LabelledWeatherForecast
 
 
-class Frame:
+class TimeFrame:
 
     def __init__(self, min_power_watt: int, hourly_forecasts: List[LabelledWeatherForecast]):
         self.min_power_watt = min_power_watt
@@ -33,6 +33,12 @@ class Frame:
     def power_total(self) -> int:
         return sum([hourly_forecast.power_watt for hourly_forecast in self.__hourly_forecasts])
 
+    def __lt__(self, other):
+        return self.start_time < other.start_time
+
+    def __eq__(self, other):
+        return self.start_time == other.start_time
+
     def __repr__(self):
         return self.__str__()
 
@@ -40,15 +46,38 @@ class Frame:
         return self.__hourly_forecasts[0].time.strftime("%H:%M") + " -> " + self.__hourly_forecasts[-1].time.strftime("%H") + ":59" + ":  surplus=" + str(self.__surplus) + " (total " + ", ".join([str(hourly_forecast.power_watt) for hourly_forecast in self.__hourly_forecasts]) + ")"
 
 
-class ForecastNext24hours:
+class TimeFrames:
 
-    def __init__(self, pv_forecast: PvPowerForecast):
+    def __init__(self, frames: List[TimeFrame]):
+        self.__frames = sorted(frames)
+
+    def empty(self):
+        return len(self.__frames) == 0
+
+    def best(self) -> Optional[TimeFrame]:
+        if len(self.__frames) > 0:
+            return self.__frames[0]
+        else:
+            return None
+
+    def all(self) -> List[TimeFrame]:
+        return list(self.__frames)
+
+
+class Next24hours:
+
+    def __init__(self, predictions: Dict[datetime, LabelledWeatherForecast]):
+        self.predictions = predictions
+
+    @staticmethod
+    def of(pv_forecast: PvPowerForecast):
         now = datetime.strptime((datetime.now()).strftime("%d.%m.%Y %H"), "%d.%m.%Y %H")
-        self.predictions = {}
+        predictions = {}
         for weather_forecast in [pv_forecast.weather_forecast_service.forecast(prediction_time) for prediction_time in [now + timedelta(hours=i) for i in range(0, 40)]]:
-            predicted_value = pv_forecast.predict_by_weather_forecast(weather_forecast)
+            predicted_value = pv_forecast.current_power_reading(weather_forecast)
             if predicted_value is not None:
-                self.predictions[weather_forecast.time] = LabelledWeatherForecast.create(weather_forecast, predicted_value)
+                predictions[weather_forecast.time] = LabelledWeatherForecast.create(weather_forecast, predicted_value)
+        return Next24hours(predictions)
 
     def __prediction_values(self) -> List[int]:
         return [forecast.power_watt for forecast in self.predictions.values() if forecast.time <= (datetime.now() + timedelta(hours=24))]
@@ -56,23 +85,17 @@ class ForecastNext24hours:
     def peek(self) -> int:
         return max(self.__prediction_values())
 
-    def power_at(self, time: datetime) -> int:
-        for weather_forecast in self.predictions.keys():
-            if weather_forecast.time.strftime("%d.%m.%Y %H") == time.strftime("%d.%m.%Y %H"):
-                return self.predictions[weather_forecast][1]
-        return 0
-
-    def frame_extra_power(self, base_power_watt: int, width_hours: int = 1) -> List[Frame]:
+    def extra_power_frames(self, base_power_watt: int, width_hours: int = 1) -> TimeFrames:
         frames = []
         times = list(self.predictions.keys())
         for offset_hour in range(0, 24+width_hours):
             forecasts = [self.predictions[times[idx]] for idx in range(offset_hour, offset_hour + width_hours)]
-            frame = Frame(base_power_watt, forecasts)
+            frame = TimeFrame(base_power_watt, forecasts)
             frames.append(frame)
         frames = [slot for slot in frames if slot.surplus_total > 0]
         frames = [slot for slot in frames if slot.start_time <= datetime.now() + timedelta(hours=24)]
         frames = sorted(frames, key=lambda slot: slot.surplus_total, reverse=True)
-        return frames
+        return TimeFrames(frames)
 
     def __str__(self):
         txt = ""
